@@ -11,7 +11,7 @@ use Env qw( @PKG_CONFIG_PATH );
 use Config ();
 
 # ABSTRACT: Build external dependencies for use in CPAN
-our $VERSION = '1.42'; # VERSION
+our $VERSION = '1.46'; # VERSION
 
 
 sub _path { goto \&Path::Tiny::path }
@@ -216,7 +216,7 @@ sub checkpoint
   my($self) = @_;
   my $root = $self->root;
   _path("$root/state.json")->spew(
-    JSON::PP->new->pretty->encode({
+    JSON::PP->new->pretty->canonical(1)->encode({
       install => $self->install_prop,
       runtime => $self->runtime_prop,
       args    => $self->{args},
@@ -1135,7 +1135,7 @@ Alien::Build - Build external dependencies for use in CPAN
 
 =head1 VERSION
 
-version 1.42
+version 1.46
 
 =head1 SYNOPSIS
 
@@ -2028,7 +2028,7 @@ Shawn Laffan (SLAFFAN)
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by Graham Ollis.
+This software is copyright (c) 2011-2018 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
