@@ -6,8 +6,7 @@ use Alien::Build::Plugin;
 use Carp ();
 
 # ABSTRACT: Plugin to filter known good versions
-our $VERSION = '1.99_01'; # TRIAL VERSION
-$VERSION = eval $VERSION; ## no critic (BuiltinFunctions::ProhibitStringyEval)
+our $VERSION = '1.46'; # VERSION
 
 
 has '+filter' => sub { Carp::croak("The filter property is required for the Prefer::GoodVersion plugin") };
@@ -17,9 +16,9 @@ sub init
   my($self, $meta) = @_;
 
   $meta->add_requires('configure', __PACKAGE__, '1.44');
-
+  
   my $filter;
-
+  
   if(ref($self->filter) eq '')
   {
     my $string = $self->filter;
@@ -45,13 +44,13 @@ sub init
   {
     Carp::croak("unknown filter type for Prefer::GoodVersion");
   }
-
+  
   $meta->around_hook(
     prefer => sub {
       my($orig, $build, @therest) = @_;
       my $res1 = $orig->($build, @therest);
       return $res1 unless $res1->{type} eq 'list';
-
+      
       return {
         type => 'list',
         list => [
@@ -76,7 +75,7 @@ Alien::Build::Plugin::Prefer::GoodVersion - Plugin to filter known good versions
 
 =head1 VERSION
 
-version 1.99_01
+version 1.46
 
 =head1 SYNOPSIS
 
@@ -85,10 +84,9 @@ version 1.99_01
 
 =head1 DESCRIPTION
 
-This plugin allows you to specify one or more good versions of a library.  This doesn't affect
-a system install at all.  This plugin does the opposite of the C<Prefer::BadVersion> plugin.
-You need need a Prefer plugin that filters and sorts files first.  You may specify the filter
-in one of three ways:
+This plugin allows you to specify one ore more good versions of a library.  This plugin does
+the opposite of the C<Prefer::BadVersion> plugin.  You need need a Prefer plugin that filters
+and sorts files first.  You may specify the filter in one of three ways:
 
 =over
 
@@ -136,9 +134,6 @@ Filter entries that match the filter.
 If you are using the string or array mode, then you need an existing Prefer plugin that sets the
 version number for each file candidate, such as L<Alien::Build::Plugin::Prefer::SortVersions>.
 
-Unless you want to exclude the latest version from a share install, this plugin isn't really
-that useful.  It has no effect on system installs, which may not be obvious at first.
-
 =head1 SEE ALSO
 
 =over 4
@@ -159,7 +154,7 @@ Contributors:
 
 Diab Jerius (DJERIUS)
 
-Roy Storey (KIWIROY)
+Roy Storey
 
 Ilya Pavlov
 
@@ -207,11 +202,9 @@ Shoichi Kaji (SKAJI)
 
 Shawn Laffan (SLAFFAN)
 
-Paul Evans (leonerd, PEVANS)
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011-2020 by Graham Ollis.
+This software is copyright (c) 2011-2018 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
